==> appng-cli-1.14.4-sources.jar: org/appng/cli/prettytable/TableConstants.java <==
/*
 * Copyright 2011-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.appng.cli.prettytable;

/**
 * Some constant values used when dealing with {@link PrettyTable}s.
 * 
 * @author Matthias Herlitzius
 * 
 */
public class TableConstants {

	public static final String ID = "ID";
	public static final String NAME = "Name";
	public static final String USER_NAME = "User name";
	public static final String REAL_NAME = "Real name";
	public static final String EMAIL = "E-Mail";
	public static final String DESCRIPTION = "Description";
	public static final String LANGUAGE = "Language";
	public static final String TYPE = "Type";
	public static final String MODE = "Mode";
	public static final String URI = "URI";
	public static final String HOST = "Host";
	public static final String DOMAIN = "Domain";
	public static final String IS_ACTIVE = "Is active";
	public static final String IS_ALIAS = "Is alias";
	public static final String DISPLAY_NAME = "Display name";
	public static final String CORE_APPLICATION = "Core application";
	public static final String FILEBASED = "Filebased";
	public static final String HIDDEN = "Hidden";
	public static final String VALUE = "Value";
	public static final String DEFAULTVALUE = "Default value";
	public static final String CHANGED = "Changed";
	public static final String APPLICATION = "Application";

	private TableConstants() {
	}

}

==> appng-cli-1.15.0-sources.jar: org/appng/cli/prettytable/TableConstants.java <==
/*
 * Copyright 2011-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.appng.cli.prettytable;

/**
 * Some constant values used when dealing with {@link PrettyTable}s.
 * 
 * @author Matthias Herlitzius
 * 
 */
public class TableConstants {

	public static final String ID = "ID";
	public static final String NAME = "Name";
	public static final String USER_NAME = "User name";
	public static final String REAL_NAME = "Real name";
	public static final String EMAIL = "E-Mail";
	public static final String DESCRIPTION = "Description";
	public static final String LANGUAGE = "Language";
	public static final String TYPE = "Type";
	public static final String MODE = "Mode";
	public static final String URI = "URI";
	public static final String HOST = "Host";
	public static final String DOMAIN = "Domain";
	public static final String IS_ACTIVE = "Is active";
	public static final String IS_ALIAS = "Is alias";
	public static final String DISPLAY_NAME = "Display name";
	public static final String PRIVILEGED = "Privileged";
	public static final String FILEBASED = "Filebased";
	public static final String HIDDEN = "Hidden";
	public static final String VALUE = "Value";
	public static final String DEFAULTVALUE = "Default value";
	public static final String CHANGED = "Changed";
	public static final String APPLICATION = "Application";

	private TableConstants() {
	}

}
